==> redux-1.0.15.tgz: package/lib/immutable/ThemeToggle/tests/index.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactRedux = require("react-redux");

var _enzyme = require("enzyme");

var _redux = require("redux");

var _reduxImmutable = require("redux-immutable");

var _theme = _interopRequireDefault(require("bootstrap-styled/lib/theme"));

var _actions = require("../../../actions");

var _reducer = _interopRequireDefault(require("../../reducer"));

var _ = _interopRequireWildcard(require(".."));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable function-paren-newline */
describe('<ThemeToggle />', function () {
  var store;
  beforeAll(function () {
    store = (0, _redux.createStore)((0, _reduxImmutable.combineReducers)({
      'bs.redux': _reducer.default
    }));
  });
  it('should render the default language messages', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRedux.Provider, {
      store: store
    }, _react.default.createElement(_.default, null)));
    expect(renderedComponent.contains(_react.default.createElement(_.default, null))).toBe(true);
  });
  describe('mapDispatchToProps', function () {
    describe('onToggle', function () {
      it('should be injected', function () {
        var dispatch = jest.fn();
        var result = (0, _.mapDispatchToProps)(dispatch);
        expect(result.onToggle).toBeDefined();
      });
      it('should dispatch onToggle when called', function () {
        var dispatch = jest.fn();
        var result = (0, _.mapDispatchToProps)(dispatch);
        var evt = {
          target: {
            value: _theme.default
          }
        };
        result.onToggle(evt);
        expect(dispatch).toHaveBeenCalledWith((0, _actions.changeTheme)(_theme.default));
      });
    });
  });
});

==> redux-1.1.1.tgz: package/lib/immutable/ThemeToggle/tests/index.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactRedux = require("react-redux");

var _enzyme = require("enzyme");

var _redux = require("redux");

var _reduxImmutable = require("redux-immutable");

var _theme = _interopRequireDefault(require("bootstrap-styled/lib/theme"));

var _actions = require("../../../actions");

var _reducer = _interopRequireDefault(require("../../reducer"));

var _constants = require("../../../constants");

var _ = _interopRequireWildcard(require(".."));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable function-paren-newline */
describe('<ThemeToggle />', function () {
  var store;
  beforeAll(function () {
    store = (0, _redux.createStore)((0, _reduxImmutable.combineReducers)(_defineProperty({}, _constants.REDUX_BS_KEY, _reducer.default)));
  });
  it('should render the default language messages', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_reactRedux.Provider, {
      store: store
    }, _react.default.createElement(_.default, null)));
    expect(renderedComponent.contains(_react.default.createElement(_.default, null))).toBe(true);
  });
  describe('mapDispatchToProps', function () {
    describe('onToggle', function () {
      it('should be injected', function () {
        var dispatch = jest.fn();
        var result = (0, _.mapDispatchToProps)(dispatch);
        expect(result.onToggle).toBeDefined();
      });
      it('should dispatch onToggle when called', function () {
        var dispatch = jest.fn();
        var result = (0, _.mapDispatchToProps)(dispatch);
        var evt = {
          target: {
            value: _theme.default
          }
        };
        result.onToggle(evt);
        expect(dispatch).toHaveBeenCalledWith((0, _actions.changeTheme)(_theme.default));
      });
    });
  });
});
